Description Usage Arguments Examples
View source: R/simulation_related_functions.R
function to create a additive or dominance kinship matrix from a AlphaSimR pop-class object. A wrapper for the kinship() function.
1 | makeKinship(pop, SP, type, snpsORqtl = "snps")
|
pop |
pop-class object from AlphaSimR |
SP |
simulation parameters from AlphaSimR |
type |
string, "add" or "dom". type="add" gives same as rrBLUP::A.mat(), i.e. Van Raden, Method 1. type="dom" gives classical parameterization according to Vitezica et al. 2013. |
snpsORqtl |
string, "snps" (default) or "qtl". Determines which loci are used to compute the GRM. |
1 | K<-makeKinship(pop, SP, type="add")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.