Description Usage Arguments Value
Predict the mean breeding value of each family, for a single trait, given parental allelic dosages and (posterior mean) marker effects. NOTE: Marker effects should represent allele substitution effects. Either by fitting an additive-only model OR an genotypic-partitioned additive+dominance model, with allele sub effects computed as a+d(q-p), where q and p are allele freqs in the training pop. used.
1 2 3 4 5 6 | predCrossMeanBVsOneTrait(
Trait,
CrossesToPredict,
doseMat,
postMeanAlleleSubEffects
)
|
Trait |
string, label of trait (name in list of postMeanAddEffects) to compute |
CrossesToPredict |
data.frame or tibble, col/colnames: sireID, damID. sireID and damID must both be in the haploMat. |
doseMat |
dosage matrix. Assumes SNPs in M coded 0, 1, 2 (requires rounding dosages to integers). M is Nind x Mrow, numeric matrix, with row/colnames to indicate SNP/ind ID |
postMeanAlleleSubEffects |
list of named vectors (or column matrices) with the posterior mean ALLELE SUBSTITUTION marker effects. |
tibble with parental GEBV and the pred Mean GEBV (mean of parents) for each cross.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.