Description Usage Arguments Value
Predict the total genetic merit of the cross based on a model with additive+dominance marker effects. For each family , for a single trait, given parental allelic dosages and (posterior mean) marker effects. Eqn. 14.6 Falconer+MacKay, and elsewhere G = sum( 𝑎(𝑝 − 𝑞 − 𝑦) + 𝑑[2𝑝𝑞 + 𝑦(𝑝 − 𝑞)] ) a and d being the additive and dominance effects p and q being the allele frequencies of one parent y is the difference of freq. between the two parents
1 2 3 4 5 6 7 | predCrossMeanGVsOneTrait(
Trait,
CrossesToPredict,
doseMat,
postMeanAddEffects,
postMeanDomEffects
)
|
Trait |
string, label of trait (name in list of postMeanAddEffects) to compute |
CrossesToPredict |
data.frame or tibble, col/colnames: sireID, damID. sireID and damID must both be in the haploMat. |
doseMat |
dosage matrix. Assumes SNPs in M coded 0, 1, 2 (requires rounding dosages to integers). M is Nind x Mrow, numeric matrix, with row/colnames to indicate SNP/ind ID |
postMeanAddEffects |
list of named vectors (or column matrices) with the posterior mean ADDITIVE marker effects. |
postMeanDomEffects |
list of named vectors (or column matrices) with the posterior mean DOMINANCE marker effects. |
tibble with predicted mean GV for each family
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.